/*
 * "China" theme for Dotclear
 * --------------------------
 * Author: Thomas PENIN
 * Website: http://www.voyage-est.com
 * License: GNU/GPL
 * --------------------------
 * Based on the "dcChristmas" theme version 1.0 by Mathieu M (http://www.html-edition.com/)
 */

/*!
 * @instructions To generate accented pinyin, use code like the following one in the Dotclear XHTML editor:
 * 		   <py>ni3hao3</py>
 * 		 or
 * 		   <pyb>ni3hao3</pyb>
 * This script will then convert the pinyin while keeping the markup
 */

/*!
 * @abstract Function to transform pinyin of the form "ni3hao3" to accented pinyin
 * @discussion To be called when the document is ready. The pinyin to transform must be
 * between "py" or "pyb" markup
 */
function transformPinyin() {
  /** 
  * Copyright Alex Amies, 2008
  * An associative array of mappings from number based to accented pinyin
  */
  var pinyin = {
    a1 : "ā",
    a2 : "á",
    a3 : "ǎ",
    a4 : "à",
    a: "a",
    ai1 : "āi",
    ai2 : "ái",
    ai3 : "ǎi",
    ai4 : "ài",
    ai : "ai",
    an1 : "ān",
    an2 : "án",
    an3 : "ǎn",
    an4 : "àn",
    an : "an",
    ang1 : "āng",
    ang2 : "áng",
    ang3 : "ǎng",
    ang4 : "àng",
    ang : "ang",
    ao1 : "āo",
    ao2 : "áo",
    ao3 : "ǎo",
    ao4 : "ào",
    ao : "ao",
    ba1 : "bā",
    ba2 : "bá",
    ba3 : "bǎ",
    ba4 : "bà",
    ba : "ba",
    bai1 : "bāi",
    bai2 : "bái",
    bai3 : "bǎi",
    bai4 : "bài",
    bai : "bai",
    ban1 : "bān",
    ban2 : "bán",
    ban3 : "bǎn",
    ban4 : "bàn",
    ban : "ban",
    bang1 : "bāng",
    bang2 : "báng",
    bang3 : "bǎng",
    bang4 : "bàng",
    bang : "bang",
    bao1 : "bāo",
    bao2 : "báo",
    bao3 : "bǎo",
    bao4 : "bào",
    bao : "bao",
    bei1 : "bēi",
    bei2 : "béi",
    bei3 : "běi",
    bei4 : "bèi",
    bei : "bei",
    ben1 : "bēn",
    ben2 : "bén",
    ben3 : "běn",
    ben4 : "bèn",
    ben : "ben",
    beng1 : "bēng",
    beng2 : "béng",
    beng3 : "běng",
    beng4 : "bèng",
    beng : "beng",
    bi1 : "bī",
    bi2 : "bí",
    bi3 : "bǐ",
    bi4 : "bì",
    bi : "bi",
    bian1 : "biān",
    bian2 : "bián",
    bian3 : "biǎn",
    bian4 : "biàn",
    bian : "bian",
    biao1 : "biāo",
    biao2 : "biáo",
    biao3 : "biǎo",
    biao4 : "biào",
    biao : "biao",
    bie1 : "biē",
    bie2 : "bié",
    bie3 : "biě",
    bie4 : "biè",
    bie : "bie",
    bin1 : "bīn",
    bin2 : "bín",
    bin3 : "bǐn",
    bin4 : "bìn",
    bin : "bin",
    bing1 : "bīng",
    bing2 : "bíng",
    bing3 : "bǐng",
    bing4 : "bìng",
    bing : "bing",
    bo1 : "bō",
    bo2 : "bó",
    bo3 : "bǒ",
    bo4 : "bò",
    bo : "bo",
    bu1 : "bū",
    bu2 : "bú",
    bu3 : "bǔ",
    bu4 : "bù",
    bu : "bu",
    ca1 : "cā",
    ca2 : "cá",
    ca3 : "cǎ",
    ca4 : "cà",
    ca : "ca",
    cai1 : "cāi",
    cai2 : "cái",
    cai3 : "cǎi",
    cai4 : "cài",
    cai : "cai",
    can1 : "cān",
    can2 : "cán",
    can3 : "cǎn",
    can4 : "càn",
    can : "can",
    cang1 : "cāng",
    cang2 : "cáng",
    cang3 : "cǎng",
    cang4 : "càng",
    cang : "cang",
    cao1 : "cāo",
    cao2 : "cáo",
    cao3 : "cǎo",
    cao4 : "cào",
    cao : "cao",
    ce1 : "cē",
    ce2 : "cé",
    ce3 : "cě",
    ce4 : "cè",
    ce : "ce",
    cen1 : "cēn",
    cen2 : "cén",
    ceng1 : "cēng",
    ceng2 : "céng",
    ceng3 : "cěng",
    ceng4 : "cèng",
    ceng : "ceng",
    cha1 : "chā",
    cha2 : "chá",
    cha3 : "chǎ",
    cha4 : "chà",
    cha : "cha",
    chai1 : "chāi",
    chai2 : "chái",
    chai3 : "chǎi",
    chai4 : "chài",
    chai : "chai",
    chan1 : "chān",
    chan2 : "chán",
    chan3 : "chǎn",
    chan4 : "chàn",
    chan : "chan",
    chang1 : "chāng",
    chang2 : "cháng",
    chang3 : "chǎng",
    chang4 : "chàng",
    chang : "chang",
    chao1 : "chāo",
    chao2 : "cháo",
    chao3 : "chǎo",
    chao4 : "chào",
    chao : "chao",
    che1 : "chē",
    che2 : "ché",
    che3 : "chě",
    che4 : "chè",
    che : "che",
    chen1 : "chēn",
    chen2 : "chén",
    chen3 : "chěn",
    chen4 : "chèn",
    chen : "chen",
    cheng1 : "chēng",
    cheng2 : "chéng",
    cheng3 : "chěng",
    cheng4 : "chèng",
    cheng : "cheng",
    chi1 : "chī",
    chi2 : "chí",
    chi3 : "chǐ",
    chi4 : "chì",
    chi : "chi",
    chong1 : "chōng",
    chong2 : "chóng",
    chong3 : "chǒng",
    chong4 : "chòng",
    chong : "chong",
    chou1 : "chōu",
    chou2 : "chóu",
    chou3 : "chǒu",
    chou4 : "chòu",
    chou : "chou",
    chu1 : "chū",
    chu2 : "chú",
    chu3 : "chǔ",
    chu4 : "chù",
    chu : "chu",
    chuai1 : "chuāi",
    chuai2 : "chuái",
    chuai3 : "chuǎi",
    chuai4 : "chuài",
    chuai : "chuai",
    chuan1 : "chuān",
    chuan2 : "chuán",
    chuan3 : "chuǎn",
    chuan4 : "chuàn",
    chuan : "chuan",
    chuang1 : "chuāng",
    chuang2 : "chuáng",
    chuang3 : "chuǎng",
    chuang4 : "chuàng",
    chuang : "chuang",
    chui1 : "chuī",
    chui2 : "chuí",
    chui3 : "chuǐ",
    chui4 : "chuì",
    chui : "chui",
    chun1 : "chūn",
    chun2 : "chún",
    chun3 : "chǔn",
    chun4 : "chùn",
    chun : "chun",
    chuo1 : "chuō",
    chuo2 : "chuó",
    ci1 : "cī",
    ci2 : "cí",
    ci3 : "cǐ",
    ci4 : "cì",
    ci : "ci",
    cong1 : "cōng",
    cong2 : "cóng",
    cong3 : "cǒng",
    cong4 : "còng",
    cong : "cong",
    cou1 : "cōu",
    cu1 : "cū",
    cu2 : "cú",
    cu3 : "cǔ",
    cu4 : "cù",
    cu : "cu",
    cuan1 : "cuān",
    cuan2 : "cuán",
    cuan4 : "cuàn",
    cui1 : "cuī",
    cui2 : "cuí",
    cui3 : "cuǐ",
    cui4 : "cuì",
    cui : "cui",
    cun1 : "cūn",
    cun2 : "cún",
    cun3 : "cǔn",
    cun4 : "cùn",
    cun : "cun",
    cuo1 : "cuō",
    cuo2 : "cuó",
    cuo3 : "cuǒ",
    cuo4 : "cuò",
    cuo : "cuo",
    da1 : "dā",
    da2 : "dá",
    da3 : "dǎ",
    da4 : "dà",
    da : "da",
    dai1 : "dāi",
    dai2 : "dái",
    dai3 : "dǎi",
    dai4 : "dài",
    dai : "dai",
    dan1 : "dān",
    dan2 : "dán",
    dan3 : "dǎn",
    dan4 : "dàn",
    dan : "dan",
    dang1 : "dāng",
    dang2 : "dáng",
    dang3 : "dǎng",
    dang4 : "dàng",
    dang : "dang",
    dao1 : "dāo",
    dao2 : "dáo",
    dao3 : "dǎo",
    dao4 : "dào",
    dao : "dao",
    de2 : "dé",
    de : "de",
    dei3 : "děi",
    den4 : "dèn",
    deng1 : "dēng",
    deng3 : "děng",
    deng4 : "dèng",
    di1 : "dī",
    di2 : "dí",
    di3 : "dǐ",
    di4 : "dì",
    di : "di",
    dian1 : "diān",
    dian2 : "dián",
    dian3 : "diǎn",
    dian4 : "diàn",
    dian : "dian",
    diao1 : "diāo",
    diao4 : "diào",
    die1 : "diē",
    die2 : "dié",
    ding1 : "dīng",
    ding3 : "dǐng",
    ding4 : "dìng",
    diu1 : "diū",
    dong1 : "dōng",
    dong3 : "dǒng",
    dong4 : "dòng",
    dou1 : "dōu",
    dou2 : "dóu",
    dou3 : "dǒu",
    dou4 : "dòu",
    dou : "dou",
    du1 : "dū",
    du2 : "dú",
    du3 : "dǔ",
    du4 : "dù",
    du : "du",
    duan1 : "duān",
    duan3 : "duǎn",
    duan4 : "duàn",
    duan : "duan",
    dui1 : "duī",
    dui4 : "duì",
    dun1 : "dūn",
    dun4 : "dùn",
    duo1 : "duō",
    duo2 : "duó",
    duo3 : "duǒ",
    duo4 : "duò",
    e1 : "ē",
    e2 : "é",
    e3 : "ě",
    e4 : "è",
    ei1 : "ēi",
    ei2 : "éi",
    ei3 : "ěi",
    ei4 : "èi",
    en1 : "ēn",
    en4 : "èn",
    er2 : "ér",
    er3 : "ěr",
    er4 : "èr",
    fa1 : "fā",
    fa2 : "fá",
    fa3 : "fǎ",
    fa4 : "fà",
    fa : "fa",
    fan1 : "fān",
    fan2 : "fán",
    fan3 : "fǎn",
    fan4 : "fàn",
    fan : "fan",
    fang1 : "fāng",
    fang2 : "fáng",
    fang3 : "fǎng",
    fang4 : "fàng",
    fang : "fang",
    fei1 : "fēi",
    fei2 : "féi",
    fei3 : "fěi",
    fei4 : "fèi",
    fei : "fei",
    fen1 : "fēn",
    fen2 : "fén",
    fen3 : "fěn",
    fen4 : "fèn",
    fen : "fen",
    feng1 : "fēng",
    feng2 : "féng",
    feng3 : "fěng",
    feng4 : "fèng",
    feng : "feng",
    fo2 : "fó",
    fou3 : "fǒu",
    fu1 : "fū",
    fu2 : "fú",
    fu3 : "fǔ",
    fu4 : "fù",
    fu : "fu",
    ga1 : "gā",
    ga2 : "gá",
    ga4 : "gà",
    gai1 : "gāi",
    gai3 : "gǎi",
    gai4 : "gài",
    gan1 : "gān",
    gan2 : "gán",
    gan3 : "gǎn",
    gan4 : "gàn",
    gan : "gan",
    gang1 : "gāng",
    gang2 : "gáng",
    gang3 : "gǎng",
    gang4 : "gàng",
    gang : "gang",
    gao1 : "gāo",
    gao2 : "gáo",
    gao3 : "gǎo",
    gao4 : "gào",
    gao : "gao",
    ge1 : "gē",
    ge2 : "gé",
    ge3 : "gě",
    ge4 : "gè",
    ge : "ge",
    gei3 : "gěi",
    gen1 : "gēn",
    gen2 : "gén",
    gen3 : "gěn",
    gen4 : "gèn",
    geng1 : "gēng",
    geng3 : "gěng",
    geng4 : "gèng",
    gong1 : "gōng",
    gong3 : "gǒng",
    gong4 : "gòng",
    gou1 : "gōu",
    gou3 : "gǒu",
    gou4 : "gòu",
    gu1 : "gū",
    gu2 : "gú",
    gu3 : "gǔ",
    gu4 : "gù",
    gua1 : "guā",
    gua3 : "guǎ",
    gua4 : "guà",
    guai1 : "guāi",
    guai3 : "guǎi",
    guai4 : "guài",
    guan1 : "guān",
    guan3 : "guǎn",
    guan4 : "guàn",
    guang1 : "guāng",
    guang3 : "guǎng",
    guang4 : "guàng",
    gui1 : "guī",
    gui3 : "guǐ",
    gui4 : "guì",
    gun3 : "gǔn",
    gun4 : "gùn",
    guo1 : "guō",
    guo2 : "guó",
    guo3 : "guǒ",
    guo4 : "guò",
    ha1 : "hā",
    ha2 : "há",
    ha3 : "hǎ",
    ha4 : "hà",
    hai1 : "hāi",
    hai2 : "hái",
    hai3 : "hǎi",
    hai4 : "hài",
    han1 : "hān",
    han2 : "hán",
    han3 : "hǎn",
    han4 : "hàn",
    hang1 : "hāng",
    hang2 : "háng",
    hang3 : "hǎng",
    hang4 : "hàng",
    hao1 : "hāo",
    hao2 : "háo",
    hao3 : "hǎo",
    hao4 : "hào",
    he1 : "hē",
    he2 : "hé",
    he4 : "hè",
    hei1 : "hēi",
    hen2 : "hén",
    hen3 : "hěn",
    hen4 : "hèn",
    heng1 : "hēng",
    heng2 : "héng",
    heng4 : "hèng",
    hng : "hng",
    hong1 : "hōng",
    hong2 : "hóng",
    hong3 : "hǒng",
    hong4 : "hòng",
    hou1 : "hōu",
    hou2 : "hóu",
    hou3 : "hǒu",
    hou4 : "hòu",
    hu1 : "hū",
    hu2 : "hú",
    hu3 : "hǔ",
    hu4 : "hù",
    hua1 : "huā",
    hua2 : "huá",
    hua4 : "huà",
    huai2 : "huái",
    huai4 : "huài",
    huan1 : "huān",
    huan2 : "huán",
    huan3 : "huǎn",
    huan4 : "huàn",
    huang1 : "huāng",
    huang2 : "huáng",
    huang3 : "huǎng",
    huang4 : "huàng",
    hui1 : "huī",
    hui2 : "huí",
    hui3 : "huǐ",
    hui4 : "huì",
    hun1 : "hūn",
    hun2 : "hún",
    hun3 : "hǔn",
    hun4 : "hùn",
    huo1 : "huō",
    huo2 : "huó",
    huo3 : "huǒ",
    huo4 : "huò",
    ji1 : "jī",
    ji2 : "jí",
    ji3 : "jǐ",
    ji4 : "jì",
    jia1 : "jiā",
    jia2 : "jiá",
    jia3 : "jiǎ",
    jia4 : "jià",
    jian1 : "jiān",
    jian3 : "jiǎn",
    jian4 : "jiàn",
    jiang1 : "jiāng",
    jiang3 : "jiǎng",
    jiang4 : "jiàng",
    jiao1 : "jiāo",
    jiao2 : "jiáo",
    jiao3 : "jiǎo",
    jiao4 : "jiào",
    jie1 : "jiē",
    jie2 : "jié",
    jie3 : "jiě",
    jie4 : "jiè",
    jin1 : "jīn",
    jin3 : "jǐn",
    jin4 : "jìn",
    jing1 : "jīng",
    jing2 : "jíng",
    jing3 : "jǐng",
    jing4 : "jìng",
    jiong1 : "jiōng",
    jiong3 : "jiǒng",
    jiu1 : "jiū",
    jiu3 : "jiǔ",
    jiu4 : "jiù",
    ju1 : "jū",
    ju2 : "jú",
    ju3 : "jǔ",
    ju4 : "jù",
    juan1 : "juān",
    juan3 : "juǎn",
    juan4 : "juàn",
    jue1 : "juē",
    jue2 : "jué",
    jue3 : "juě",
    jue4 : "juè",
    jun1 : "jūn",
    jun4 : "jùn",
    ka1 : "kā",
    ka3 : "kǎ",
    kai1 : "kāi",
    kai3 : "kǎi",
    kai4 : "kài",
    kan1 : "kān",
    kan3 : "kǎn",
    kan4 : "kàn",
    kang1 : "kāng",
    kang2 : "káng",
    kang4 : "kàng",
    kao1 : "kāo",
    kao3 : "kǎo",
    kao4 : "kào",
    ke1 : "kē",
    ke2 : "ké",
    ke3 : "kě",
    ke4 : "kè",
    kei1 : "kēi",
    ken3 : "kěn",
    keng1 : "kēng",
    kong1 : "kōng",
    kong3 : "kǒng",
    kong4 : "kòng",
    kou1 : "kōu",
    kou3 : "kǒu",
    kou4 : "kòu",
    ku1 : "kū",
    ku3 : "kǔ",
    ku4 : "kù",
    kua1 : "kuā",
    kua3 : "kuǎ",
    kua4 : "kuà",
    kuai3 : "kuǎi",
    kuai4 : "kuài",
    kuan1 : "kuān",
    kuan3 : "kuǎn",
    kuang1 : "kuāng",
    kuang2 : "kuáng",
    kuang4 : "kuàng",
    kui1 : "kuī",
    kui2 : "kuí",
    kui3 : "kuǐ",
    kui4 : "kuì",
    kun1 : "kūn",
    kun3 : "kǔn",
    kun4 : "kùn",
    kuo4 : "kuò",
    la1 : "lā",
    la2 : "lá",
    la3 : "lǎ",
    la4 : "là",
    la : "la",
    lai2 : "lái",
    lai4 : "lài",
    lan2 : "lán",
    lan3 : "lǎn",
    lan4 : "làn",
    lang1 : "lāng",
    lang2 : "láng",
    lang3 : "lǎng",
    lang4 : "làng",
    lao1 : "lāo",
    lao2 : "láo",
    lao3 : "lǎo",
    lao4 : "lào",
    le4 : "lè",
    le : "le",
    lei1 : "lēi",
    lei2 : "léi",
    lei3 : "lěi",
    lei4 : "lèi",
    leng2 : "léng",
    leng3 : "lěng",
    leng4 : "lèng",
    li1 : "lī",
    li2 : "lí",
    li3 : "lǐ",
    li4 : "lì",
    li : "li",
    lia3 : "liǎ",
    lian2 : "lián",
    lian3 : "liǎn",
    lian4 : "liàn",
    liang2 : "liáng",
    liang3 : "liǎng",
    liang4 : "liàng",
    liao1 : "liāo",
    liao2 : "liáo",
    liao3 : "liǎo",
    liao4 : "liào",
    lie1 : "liē",
    lie3 : "liě",
    lie4 : "liè",
    lin2 : "lín",
    lin3 : "lǐn",
    lin4 : "lìn",
    ling1 : "līng",
    ling2 : "líng",
    ling3 : "lǐng",
    ling4 : "lìng",
    liu1 : "liū",
    liu2 : "liú",
    liu3 : "liǔ",
    liu4 : "liù",
    lo : "lo",
    long1 : "lōng",
    long2 : "lóng",
    long3 : "lǒng",
    long4 : "lòng",
    lou1 : "lōu",
    lou2 : "lóu",
    lou3 : "lǒu",
    lou4 : "lòu",
    lou : "lou",
    lu1 : "lū",
    lu2 : "lú",
    lu3 : "lǔ",
    lu4 : "lù",
    lu : "lu",
    lv2 : "lǘ",
    lv3 : "lǚ",
    lv4 : "lǜ",
    luan2 : "luán",
    luan3 : "luǎn",
    luan4 : "luàn",
    lve4 : "lüè",
    lun1 : "lūn",
    lun2 : "lún",
    lun4 : "lùn",
    luo1 : "luō",
    luo2 : "luó",
    luo3 : "luǒ",
    luo4 : "luò",
    m2 : "m2",
    m4 : "m4",
    ma1 : "mā",
    ma2 : "má",
    ma3 : "mǎ",
    ma4 : "mà",
    ma : "ma",
    mai2 : "mái",
    mai3 : "mǎi",
    mai4 : "mài",
    man1 : "mān",
    man2 : "mán",
    man3 : "mǎn",
    man4 : "màn",
    mang2 : "máng",
    mang3 : "mǎng",
    mao1 : "māo",
    mao2 : "máo",
    mao3 : "mǎo",
    mao4 : "mào",
    me : "me",
    mei2 : "méi",
    mei3 : "měi",
    mei4 : "mèi",
    men1 : "mēn",
    men2 : "mén",
    men4 : "mèn",
    men : "men",
    meng1 : "mēng",
    meng2 : "méng",
    meng3 : "měng",
    meng4 : "mèng",
    mi1 : "mī",
    mi2 : "mí",
    mi3 : "mǐ",
    mi4 : "mì",
    mian2 : "mián",
    mian3 : "miǎn",
    mian4 : "miàn",
    miao1 : "miāo",
    miao2 : "miáo",
    miao3 : "miǎo",
    miao4 : "miào",
    mie1 : "miē",
    mie4 : "miè",
    min2 : "mín",
    min3 : "mǐn",
    ming2 : "míng",
    ming3 : "mǐng",
    ming4 : "mìng",
    miu4 : "miù",
    mo1 : "mō",
    mo2 : "mó",
    mo3 : "mǒ",
    mo4 : "mò",
    mou1 : "mōu",
    mou2 : "móu",
    mou3 : "mǒu",
    mu2 : "mú",
    mu3 : "mǔ",
    mu4 : "mù",
    na1 : "nā",
    na2 : "ná",
    na3 : "nǎ",
    na4 : "nà",
    na : "na",
    nai3 : "nǎi",
    nai4 : "nài",
    nan1 : "nān",
    nan2 : "nán",
    nan3 : "nǎn",
    nan4 : "nàn",
    nang1 : "nāng",
    nang2 : "náng",
    nang3 : "nǎng",
    nang4 : "nàng",
    nao1 : "nāo",
    nao2 : "náo",
    nao3 : "nǎo",
    nao4 : "nào",
    ne4 : "nè",
    ne : "ne",
    nei3 : "něi",
    nei4 : "nèi",
    nen4 : "nèn",
    neng2 : "néng",
    ng2 : "ng2",
    ng4 : "ng4",
    ni1 : "nī",
    ni2 : "ní",
    ni3 : "nǐ",
    ni4 : "nì",
    nian1 : "niān",
    nian2 : "nián",
    nian3 : "niǎn",
    nian4 : "niàn",
    niang2 : "niáng",
    niang4 : "niàng",
    niao3 : "niǎo",
    niao4 : "niào",
    nie1 : "niē",
    nie2 : "nié",
    nie4 : "niè",
    nin2 : "nín",
    ning2 : "níng",
    ning3 : "nǐng",
    ning4 : "nìng",
    niu1 : "niū",
    niu2 : "niú",
    niu3 : "niǔ",
    niu4 : "niù",
    nong2 : "nóng",
    nong4 : "nòng",
    nou4 : "nòu",
    nu2 : "nú",
    nu3 : "nǔ",
    nu4 : "nù",
    nv3 : "nǚ",
    nv4 : "nǜ",
    nuan3: "nuǎn",
    nve4: "nüè",
    nuo2: "nuó",
    nuo4: "nuò",
    o1: "ō",
    o2: "ó",
    o3: "ǒ",
    o4: "ò",
    ou1: "ōu",
    ou3: "ǒu",
    ou4: "òu",
    pa1: "pā",
    pa2: "pá",
    pa4: "pà",
    pai1: "pāi",
    pai2: "pái",
    pai3: "pǎi",
    pai4: "pài",
    pan1: "pān",
    pan2: "pán",
    pan4: "pàn",
    pang1: "pāng",
    pang2: "páng",
    pang3: "pǎng",
    pang4: "pàng",
    pao1: "pāo",
    pao2: "páo",
    pao3: "pǎo",
    pao4: "pào",
    pei1: "pēi",
    pei2: "péi",
    pei4: "pèi",
    pen1: "pēn",
    pen2: "pén",
    pen4: "pèn",
    peng1: "pēng",
    peng2: "péng",
    peng3: "pěng",
    peng4: "pèng",
    pi1: "pī",
    pi2: "pí",
    pi3: "pǐ",
    pi4: "pì",
    pian1: "piān",
    pian2: "pián",
    pian3: "piǎn",
    pian4: "piàn",
    piao1: "piāo",
    piao2: "piáo",
    piao3: "piǎo",
    piao4: "piào",
    pie1: "piē",
    pie3: "piě",
    pin1: "pīn",
    pin2: "pín",
    pin3: "pǐn",
    pin4: "pìn",
    ping1: "pīng",
    ping2: "píng",
    po1: "pō",
    po2: "pó",
    po3: "pǒ",
    po4: "pò",
    po: "po",
    pou1: "pōu",
    pou2: "póu",
    pou3: "pǒu",
    pu1: "pū",
    pu2: "pú",
    pu3: "pǔ",
    pu4: "pù",
    qi1: "qī",
    qi2: "qí",
    qi3: "qǐ",
    qi4: "qì",
    qia1: "qiā",
    qia3: "qiǎ",
    qia4: "qià",
    qian1: "qiān",
    qian2: "qián",
    qian3: "qiǎn",
    qian4: "qiàn",
    qiang1: "qiāng",
    qiang2: "qiáng",
    qiang3: "qiǎng",
    qiang4: "qiàng",
    qiao1: "qiāo",  
    qiao2: "qiáo",  
    qiao3: "qiǎo",  
    qiao4: "qiào",
    qie1: "qiē",
    qie2: "qié",
    qie3: "qiě",
    qie4: "qiè",
    qin1: "qīn",
    qin2: "qín",
    qin3: "qǐn",
    qin4: "qìn",
    qing1: "qīng",
    qing2: "qíng",
    qing3: "qǐng",
    qing4: "qìng",
    qiong2: "qióng",
    qiu1: "qiū",
    qiu2: "qiú",
    qu1: "qū",
    qu2: "qú",
    qu3: "qǔ",
    qu4: "qù",
    quan1: "quān",
    quan2: "quán",
    quan3: "quǎn",
    quan4: "quàn",
    que1: "quē",
    que2: "qué",
    que4: "què",
    qun1: "qūn",
    qun2: "qún",
    ran2: "rán",
    ran3: "rǎn",
    rang1: "rāng",
    rang2: "ráng",
    rang3: "rǎng",
    rang4: "ràng",
    rao2: "ráo",
    rao3: "rǎo",
    rao4: "rào",
    re3: "rě",
    re4: "rè",
    ren2: "rén",
    ren3: "rěn",
    ren4: "rèn",
    reng1: "rēng",
    reng2: "réng",
    ri4: "rì",
    rong2: "róng",
    rong3: "rǒng",
    rou2: "róu",
    rou4: "ròu",
    ru2: "rú",
    ru3: "rǔ",
    ru4: "rù",
    ruan1: "ruān",
    rui3: "ruǐ",
    rui4: "ruì",
    run4: "rùn",
    ruo4: "ruò",
    sa1: "sā",
    sa3: "sǎ",
    sa4: "sà",
    sai1: "sāi",
    sai4: "sài",
    san1: "sān",
    san3: "sǎn",
    san4: "sàn",
    sao1: "sāo",
    sao3: "sǎo",
    sao4: "sào",
    se4: "sè",
    sen1: "sēn",
    seng1: "sēng",
    sha1: "shā",
    sha3: "shǎ",
    sha4: "shà",
    shai1: "shāi",
    shai3: "shǎi",
    shai4: "shài",
    shan1: "shān",
    shan3: "shǎn",
    shan4: "shàn",
    shang1: "shāng",
    shang3: "shǎng",
    shang4: "shàng",
    shang: "shang",
    shao1: "shāo",
    shao2: "sháo",
    shao3: "shǎo",
    shao4: "shào",
    she1: "shē",
    she2: "shé",
    she3: "shě",
    she4: "shè",
    shei2: "shéi",
    shen1: "shēn",
    shen2: "shén",
    shen3: "shěn",
    shen4: "shèn",
    sheng1: "shēng",
    sheng2: "shéng",
    sheng3: "shěng",
    sheng4: "shèng",
    shi1: "shī",
    shi2: "shí",
    shi3: "shǐ",
    shi4: "shì",
    shi: "shi",
    shou1: "shōu",
    shou3: "shǒu",
    shou4: "shòu",
    shu1: "shū",
    shu2: "shú",
    shu3: "shǔ",
    shu4: "shù",
    shua1: "shuā",
    shua3: "shuǎ",
    shua4: "shuà",
    shuai1: "shuāi",
    shuai3: "shuǎi",
    shuai4: "shuài",
    shuan1: "shuān",
    shuan4: "shuàn",
    shuang1: "shuāng",
    shuang3: "shuǎng",
    shui2: "shuí",
    shui3: "shuǐ",
    shui4: "shuì",
    shun3: "shǔn",
    shun4: "shùn",
    shuo1: "shuō",
    shuo4: "shuò",
    si1: "sī",
    si3: "sǐ",
    si4: "sì",
    si: "si",
    song1: "sōng",
    song3: "sǒng",
    song4: "sòng",
    sou1: "sōu",
    sou3: "sǒu",
    sou4: "sòu",
    su1: "sū",
    su2: "sú",
    su4: "sù",
    suan1: "suān",
    suan4: "suàn",
    sui1: "suī",
    sui2: "suí",
    sui3: "suǐ",
    sui4: "suì",
    sun1: "sūn",
    sun3: "sǔn",
    suo1: "suō",
    suo3: "suǒ",
    suo: "suo",
    ta1: "tā",
    ta3: "tǎ",
    ta4: "tà",
    tai1: "tāi",
    tai2: "tái",
    tai4: "tài",
    tan1: "tān",
    tan2: "tán",
    tan3: "tǎn",
    tan4: "tàn",
    tang1: "tāng",
    tang2: "táng",
    tang3: "tǎng",
    tang4: "tàng",
    tao1: "tāo",
    tao2: "táo",
    tao3: "tǎo",
    tao4: "tào",
    te4: "tè",
    tei1: "tēi",
    teng1: "tēng",
    teng2: "téng",
    ti1: "tī",
    ti2: "tí",
    ti3: "tǐ",
    ti4: "tì",
    tian1: "tiān",
    tian2: "tián",
    tian3: "tiǎn",
    tiao: "tiāo",
    tiao: "tiáo",
    tiao: "tiǎo",
    tiao: "tiào",
    tie1: "tiē",
    tie3: "tiě",
    tie4: "tiè",
    ting1: "tīng",
    ting2: "tíng",
    ting3: "tǐng",
    tong1: "tōng",
    tong2: "tóng",
    tong3: "tǒng",
    tong4: "tòng",
    tou1: "tōu",
    tou2: "tóu",
    tou4: "tòu",
    tu1: "tū",
    tu2: "tú",
    tu3: "tǔ",
    tu4: "tù",
    tuan1: "tuān",
    tuan2: "tuán",
    tui1: "tuī",
    tui2: "tuí",
    tui3: "tuǐ",
    tui4: "tuì",
    tun1: "tūn",
    tun2: "tún",
    tun3: "tǔn",
    tun4: "tùn",
    tuo1: "tuō",
    tuo2: "tuó",
    tuo3: "tuǒ",
    tuo4: "tuò",
    wa1: "wā",
    wa2: "wá",
    wa3: "wǎ",
    wa4: "wà",
    wa: "wa",
    wai1: "wāi",
    wai3: "wǎi",
    wai4: "wài",
    wan1: "wān",
    wan2: "wán",
    wan3: "wǎn",
    wan4: "wàn",
    wang1: "wāng",
    wang2: "wáng",
    wang3: "wǎng",
    wang4: "wàng",
    wei1: "wēi",
    wei2: "wéi",
    wei3: "wěi",
    wei4: "wèi",
    wen1: "wēn",
    wen2: "wén",
    wen3: "wěn",
    wen4: "wèn",
    weng1: "wēng",
    weng3: "wěng",
    weng4: "wèng",
    wo1: "wō",
    wo3: "wǒ",
    wo4: "wò",
    wu1: "wū",
    wu2: "wú",
    wu3: "wǔ",
    wu4: "wù",
    xi1: "xī",
    xi2: "xí",
    xi3: "xǐ",
    xi4: "xì",
    xia1: "xiā",
    xia2: "xiá",
    xia4: "xià",
    xian1: "xiān",
    xian2: "xián",
    xian3: "xiǎn",
    xian4: "xiàn",
    xiang1: "xiāng",
    xiang2: "xiáng",
    xiang3: "xiǎng",
    xiang4: "xiàng",
    xiao1: "xiāo",
    xiao2: "xiáo",
    xiao3: "xiǎo",
    xiao4: "xiào",
    xie1: "xiē",
    xie2: "xié",
    xie3: "xiě",
    xie4: "xiè",
    xin1: "xīn",
    xin2: "xín",
    xin4: "xìn",
    xing1: "xīng",
    xing2: "xíng",
    xing3: "xǐng",
    xing4: "xìng",
    xiong1: "xiōng",
    xiong2: "xióng",
    xiu1: "xiū",
    xiu3: "xiǔ",
    xiu4: "xiù",
    xu1: "xū",
    xu2: "xú",
    xu3: "xǔ",
    xu4: "xù",
    xu: "xu",
    xuan1: "xuān",
    xuan2: "xuán",
    xuan3: "xuǎn",
    xuan4: "xuàn",
    xue1: "xuē",
    xue2: "xué",
    xue3: "xuě",
    xue4: "xuè",
    xun1: "xūn",
    xun2: "xún",
    xun4: "xùn",
    ya1: "yā",
    ya2: "yá",
    ya3: "yǎ",
    ya4: "yà",
    ya: "ya",
    yan1: "yān",
    yan2: "yán",
    yan3: "yǎn",
    yan4: "yàn",
    yang1: "yāng",
    yang2: "yáng",
    yang3: "yǎng",
    yang4: "yàng",
    yao1: "yāo",
    yao2: "yáo",
    yao3: "yǎo",
    yao4: "yào",
    ye1: "yē",
    ye2: "yé",
    ye3: "yě",
    ye4: "yè",
    yi1: "yī",
    yi2: "yí",
    yi3: "yǐ",
    yi4: "yì",
    yin1: "yīn",
    yin2: "yín",
    yin3: "yǐn",
    yin4: "yìn",
    ying1: "yīng",
    ying2: "yíng",
    ying3: "yǐng",
    ying4: "yìng",
    yo1: "yō",
    yo: "yo",
    yong1: "yōng",
    yong2: "yóng",
    yong3: "yǒng",
    yong4: "yòng",
    you1: "yōu",
    you2: "yóu",
    you3: "yǒu",
    you4: "yòu",
    yu1: "yū",
    yu2: "yú",
    yu3: "yǔ",
    yu4: "yù",
    yuan1: "yuān",
    yuan2: "yuán",
    yuan3: "yuǎn",
    yuan4: "yuàn",
    yue1: "yuē",
    yue4: "yuè",
    yun1: "yūn",
    yun2: "yún",
    yun3: "yǔn",
    yun4: "yùn",
    za1: "zā",
    za2: "zá",
    za3: "zǎ",
    zai1: "zāi",
    zai3: "zǎi",
    zai4: "zài",
    zan1: "zān",
    zan2: "zán",
    zan3: "zǎn",
    zan4: "zàn",
    zan: "zan",
    zang1: "zāng",
    zang3: "zǎng",
    zang4: "zàng",
    zao1: "zāo",
    zao2: "záo",
    zao3: "zǎo",
    zao4: "zào",
    ze2: "zé",
    ze4: "zè",
    zei2: "zéi",
    zen3: "zěn",
    zen4: "zèn",
    zeng1: "zēng",
    zeng4: "zèng",
    zha1: "zhā",
    zha2: "zhá",
    zha3: "zhǎ",
    zha4: "zhà",
    zhai1: "zhāi",
    zhai2: "zhái",
    zhai3: "zhǎi",
    zhai4: "zhài",
    zhan1: "zhān",
    zhan3: "zhǎn",
    zhan4: "zhàn",
    zhang1: "zhāng",
    zhang3: "zhǎng",
    zhang4: "zhàng",
    zhao1: "zhāo",
    zhao2: "zháo",
    zhao3: "zhǎo",
    zhao4: "zhào",
    zhe1: "zhē",
    zhe2: "zhé",
    zhe3: "zhě",
    zhe4: "zhè",
    zhe: "zhe",
    zhei4: "zhèi",
    zhen1: "zhēn",
    zhen3: "zhěn",
    zhen4: "zhèn",
    zheng1: "zhēng",
    zheng3: "zhěng",
    zheng4: "zhèng",
    zhi1: "zhī",
    zhi2: "zhí",
    zhi3: "zhǐ",
    zhi4: "zhì",
    zhong1: "zhōng",
    zhong3: "zhǒng",
    zhong4: "zhòng",
    zhou1: "zhōu",
    zhou2: "zhóu",
    zhou3: "zhǒu",
    zhou4: "zhòu",
    zhu1: "zhū",
    zhu2: "zhú",
    zhu3: "zhǔ",
    zhu4: "zhù",
    zhua1: "zhuā",
    zhua3: "zhuǎ",
    zhuai1: "zhuāi",
    zhuai3: "zhuǎi",
    zhuai4: "zhuài",
    zhuan1: "zhuān",
    zhuan3: "zhuǎn",
    zhuan4: "zhuàn",
    zhuang1: "zhuāng",
    zhuang3: "zhuǎng",
    zhuang4: "zhuàng",
    zhui1: "zhuī",
    zhui4: "zhuì",
    zhun1: "zhūn",
    zhun3: "zhǔn",
    zhuo1: "zhuō",
    zhuo2: "zhuó",
    zi1: "zī",
    zi3: "zǐ",
    zi4: "zì",
    zong1: "zōng",
    zong3: "zǒng",
    zong4: "zòng",
    zou1: "zōu",
    zou3: "zǒu",
    zou4: "zòu",
    zu1: "zū",
    zu2: "zú",
    zu3: "zǔ",
    zuan1: "zuān",
    zuan3: "zuǎn",
    zuan4: "zuàn",
    zui3: "zuǐ",
    zui4: "zuì",
    zun1: "zūn",
    zun3: "zǔn",
    zuo1: "zuō",
    zuo2: "zuó",
    zuo3: "zuǒ",
    zuo4: "zuò"
  };
  
  /*!
   * Take a string and capitalize its first letter only
   * @param string A string that needs its first letter to be capitalized
   */
  function capitalizeFirstLetter(string)
  {
      return string.charAt(0).toUpperCase() + string.slice(1);
  }
  
  /*!
   * Take a pinyin string of the form "Ni3" (1 syllable) and turn it into accented pinyin
   * @discussion If the first letter is capitalized, this distinction is kept
   * @param string The accented pinyin string to consider
   * @return The accented pinyin, the unchanged syllable if no matching pinyin could be found
   */
  function accentPinyin(string)
  {
    var accented = string.replace(/[a-zA-Z]+[1-4]/g, function(match) {
      var firstChar = match.charAt(0);
      var firstCharIsUpperCase = (firstChar == firstChar.toUpperCase());
      var lowerCaseMatch = match.toLowerCase();
      var result = (pinyin[lowerCaseMatch]) ? pinyin[lowerCaseMatch] : match;
      if (firstCharIsUpperCase)
	result = capitalizeFirstLetter(result);
      return result;
    });
    
    return accented;
  }

  // Change all the pinyin that is of the form ni3hao3 in "py" and "pyb" markup to accented pinyin
  $("py").each(function() {
    $(this).replaceWith(function() {
      return "<py>" + accentPinyin($(this).text()) + "</py>";
    });
  });
  $("pyb").each(function() {
    $(this).replaceWith(function() {
      return "<pyb>" + accentPinyin($(this).text()) + "</pyb>";
    });
  });
}